@@ -21,7 +21,8 @@ predict_label=scAnnotate(train=pbmc1,
                          distribution="normal",
                          correction ="auto",
                          screening = "wilcox",
-                         threshold=0)
+                         threshold=0,
+                         lognormalized=TRUE)
 
 ## -----------------------------------------------------------------------------
 eva_cal(prediction = predict_label,cell_label = pbmc2[,1])
